package keyvaluedriver

import (
	"context"
	"fmt"
	"os"
	"query-service/pkg/logger"

	"github.com/go-redis/redis/v8"
)

// RedisDriver models the redis driver
type RedisDriver struct {
	client *redis.Client
}

// NewRedisDriver creates and returns a redis driver
func NewRedisDriver() *RedisDriver {
	return &RedisDriver{}
}

// Start starts the redis driver
func (d *RedisDriver) Start() {
	// Grab the redis host and port from environment vars
	redisAddress := os.Getenv("REDIS_ADDRESS")
	// redisPassword := os.Getenv("REDIS_PASSWORD")

	// Create redis client
	d.client = redis.NewClient(&redis.Options{
		Addr: redisAddress,
	})

	pong := d.client.Ping(context.Background())
	logger.Log(fmt.Sprintf("%v", pong))
}

// Get retrieves the value from the redis store that belongs to the given key
func (d *RedisDriver) Get(key *string) *string {
	value := d.client.Get(context.Background(), *key).Val()
	return &value
}

// Set sets the key value pair in the redis store
func (d *RedisDriver) Set(key *string, value interface{}) error {
	status := d.client.Set(context.Background(), *key, value, 0)
	return status.Err()
}
